# POPULUS

[![Gitter chat](https://badges.gitter.im/pipermerriam/populus.png)](https://gitter.im/pipermerriam/populus "Gitter chat")
[![Build Status](https://travis-ci.org/pipermerriam/populus.png)](https://travis-ci.org/pipermerriam/populus)
[![Documentation Status](https://readthedocs.org/projects/populus/badge/?version=latest)](https://readthedocs.org/projects/populus/?badge=latest)
[![PyPi version](https://pypip.in/v/populus/badge.png)](https://pypi.python.org/pypi/populus)
[![PyPi downloads](https://pypip.in/d/populus/badge.png)](https://pypi.python.org/pypi/populus)
   

Ethereum Development Framework


[Documentation on ReadTheDocs](http://populus.readthedocs.org/en/latest/)


## Features

- compilation (limited to solidity right now).
- deployment
- testing (using pytest)
- management of test chains
- html/css/js development server.
